ToggleControl
==========================================

.. currentmodule:: enaml.widgets.toggle_control

.. autoclass:: ToggleControl


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_toggle_control.QtToggleControl
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_toggle_control.QtToggleControl

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_toggle_control.WXToggleControl
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_toggle_control.WXToggleControl
